@@ -1,13 +1,13 @@
 # -*- coding:utf-8 -*-
 __title__ = 'cgai_socket'
-__version__ = '0.0.1'
+__version__ = '0.0.5'
 __author__ = 'Master Zhang'
 __author_email__ = '360014296@qq.com'
 __license__ = 'MulanPSL2'
-__description__ = F"""cgai_socket {__version__}
+__description__ = """cgai_socket {}
 可简单快速开启服务
 支持自定义回调函数
 
 open for any contributions, issue reporting. even if you have any idea about this package you are warmly accepted!
 just check out: https://github.com/zxzxde/cgai-socket
-"""
\ No newline at end of file
+""".format(__version__)
\ No newline at end of file
